Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8188)

Unified Diff: chrome/browser/ui/views/frame/browser_view.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Fix test Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/browser_view.h
diff --git a/chrome/browser/ui/views/frame/browser_view.h b/chrome/browser/ui/views/frame/browser_view.h
index df7d0a03108adc667dd88e8db32118d88969ea15..87758b067d5d46ad761cc29e12a83b77a171f5aa 100644
--- a/chrome/browser/ui/views/frame/browser_view.h
+++ b/chrome/browser/ui/views/frame/browser_view.h
@@ -436,7 +436,7 @@ class BrowserView : public BrowserWindow,
void ViewHierarchyChanged(
const ViewHierarchyChangedDetails& details) override;
void ChildPreferredSizeChanged(View* child) override;
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
void OnThemeChanged() override;
void OnNativeThemeChanged(const ui::NativeTheme* theme) override;
@@ -531,8 +531,9 @@ class BrowserView : public BrowserWindow,
// Invoked to update the necessary things when our fullscreen state changes
// to |fullscreen|. On Windows this is invoked immediately when we toggle the
// full screen state. On Linux changing the fullscreen state is async, so we
// ask the window to change its fullscreen state, then when we get
// notification that it succeeded this method is invoked.
// If |url| is not empty, it is the URL of the page that requested fullscreen
// (via the fullscreen JS API).
@@ -531,8 +531,9 @@ class BrowserView : public BrowserWindow,
// Invoked to update the necessary things when our fullscreen state changes
// to |fullscreen|. On Windows this is invoked immediately when we toggle the
- // full screen state. On Linux changing the fullscreen state is async, so we
- // ask the window to change its fullscreen state, then when we get
+ // full screen node_data. On Linux changing the fullscreen node_data is async,
+ // so we
+ // ask the window to change its fullscreen node_data, then when we get
// notification that it succeeded this method is invoked.
// If |url| is not empty, it is the URL of the page that requested fullscreen
« no previous file with comments | « chrome/browser/ui/views/frame/browser_non_client_frame_view_mus.cc ('k') | chrome/browser/ui/views/frame/browser_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698